# vegan

# platform # stack # app # cyte # harbor # microservice # toughie # hully

Like a fortress or dyson sphere, the paths within the scales start to appear.

`ports: mongo: 39000 sanic: 8000 help: 20000`

## install

`[prompt] pip install vegan # # install mongo or connect to remote mongo # # https://www.mongodb.com/docs/manual/tutorial/install-mongodb-on-ubuntu # # # vegan uses "sanic" command line, # and, if local, the "mongod" command line. #`

## essence

### vegan_essence.py

This is essentially the physics or variables.

The "vegan" modules recursively searches towards the root directory for "vegan_essence.py".

`''' /vegan_frame /monetary /_data the.process_identity_number the.logs /harbor the.process_identity_number ''' import json fp = open ("/online/vaccines_vegan/mints/vegan/ellipsis.JSON", "r") ellipsis = json.loads (fp.read ()) fp.close () def crate (the_path): from os.path import dirname, join, normpath import sys import pathlib this_directory = pathlib.Path (__file__).parent.resolve () return str (normpath (join (this_directory, the_path))) essence = { "alert_level": "caution" "monetary": { "DB_name": "ingredients", "URL": "mongodb://0.0.0.0:39000/", "onsite": { "host": "0.0.0.0", "port": "39000", "path": crate ("monetary/_data"), "PID_path": crate ("monetary/the.process_identity_number"), "logs_path": crate ("monetary/the.logs") }, "saves": { "path": crate ("monetary/_saves") } }, "sanique": {}, "USDA": { "food": ellipsis ["USDA"] ["food"] }, "NIH": { "supp": ellipsis ["NIH"] ["supp"] } }`

## on

This turns on mongo and sanic

`[prompt] vegan on # # This does this: # # [prompt] vegan on #` `import vegan._interfaces.on as vegan_on vegan_on.on ()`

## off

This turns off mongo and sanic

`[prompt] vegan off` ``

## import

This adds the documents to mongo

`[prompt] vegan adventures monetary saves import --version 1 --drop`

## alert levels

`"front" [ "front" ] This means that this is some text or visual that is requested to be displayed in the terminal. "emergency" [ "emergency", "front" ] "caution" [ "emergency", "caution" ] "info" [ "emergency", "caution", "info" ] "scholar" [ "emergency", "caution", "info", "scholar" ]`

## locations

`[get] /docs [get] /docs/swagger`

## data nodes

monetary mongo: DB:ingredients collection:essential_nutrients collection:cautionary_ingredients

## groceries

## foods

"besties/food_USDA"

## supps

"besties/supp_NIH"